#!/bin/ksh
# Licensed Materials - Property of IBM
# Restricted Materials of IBM
#
# Copyright IBM Corp. 2008 All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
# Release Name: omsql_621
#
#  Description: Copy the patch xml file into the depot
#               so that the remote deploy GUI panel is updated.
#
#  Parameters:
#    Tivoli Enterprise Monitoring Server Name
#
#    koq_patchdepot.sh <Tivoli Enterprise Monitoring Server Name>
#
#    CANDLEHOME, set in the environment
#
#  Returns:
#    None
#============================================================
#set -x

PATCHID=6.2.1-TIV-ITM_SQL-IF0012
XML_SRC=oq_dd_062100012.xml
XML_DST=oq_dd_062100000.xml
OQ_PROP=oq_dd.properties

# ask for the ITM 6.1 install directory if not in the environment
if [ ! -d $CANDLEHOME/tmaitm6 ]; then
  while true
  do
    echo "Enter the path of the IBM Tivoli Monitoring directory or q to quit:"
    read CANDLEHOME
    if [ "${CANDLEHOME}" = "q"  ]; then
      echo "koq_patchdepot.sh exiting..."
      exit 100
    fi
    if [ -d $CANDLEHOME/tmaitm6 ]; then
      export CANDLEHOME
      break
    else
      echo "ERROR: $CANDLEHOME/tmaitm6 was not found..."
    fi
  done
fi

# IZ30014 Get TEMS NAME
TEMSNAME=$1
if [ ! -d $CANDLEHOME/tables/$TEMSNAME ]; then
  while true
  do
    echo "Enter the correct IBM Tivoli Enterprise Monitoring Server Name or q to quit:"
    read TEMSNAME
    if [ "${TEMSNAME}" = "q"  ]; then
      echo "koq_patchdepot.sh exiting..."
      exit 100
    fi
    if [ -d $CANDLEHOME/tables/$TEMSNAME ]; then
      export TEMSNAME
      break
    else
      echo "ERROR: $CANDLEHOME/tables/$TEMSNAME was not found..."
    fi
  done
fi


# Make sure the source files are in the current running directory
if [[ ! -f $XML_SRC || ! -f $OQ_PROP ]]; then
  echo "$XML_SRC or $OQ_PROP was not found..."
  echo "You must run koq_patchdepot.sh from the extracted $PATCHID directory..."
  echo "koq_patchdepot.sh exiting..."
  exit 100
fi
cwd=`pwd`

echo "Are you sure you want to patch the depot for $PATCHID, enter (y/n):"
read ANS
if [ "$ANS" != "y"  ]; then
  echo "koq_patchdepot.sh exiting..."
  exit 100
fi

# IZ30014 Get DEPOTHOME
if [[ -z $DEPOTHOME ]]; then
  cd $CANDLEHOME/tables/$TEMSNAME
  DEPOTHOME=`grep "^DEPOTHOME" KBBENV | cut -d= -f2`
fi

# IZ30014 cd to the destination directory and do the copies
# check for DEPOTHOME and use if found
# Default DEPOTHOME is <itm_installdir>/tables/<tems_name>/depot
if [[ -d "$DEPOTHOME" ]]; then
  SRCPATH=$DEPOTHOME
else
  SRCPATH=$CANDLEHOME/tables/$TEMSNAME/depot
fi

cd $SRCPATH
FILES=`find . -name $XML_DST -type f -print`
for file in $FILES
do
  echo "Modifying $SRCPATH/$file"
  cp $cwd/$XML_SRC $file
  echo "Modifying $SRCPATH/${file%/*}/$OQ_PROP"
  cp $cwd/$OQ_PROP ${file%/*}/$OQ_PROP
done

echo "koq_patchdepot.sh completed..."

exit 0
